@@ -1,11 +1,24 @@
 # coding: utf-8
 
+# Standard Python libraries
+import io
+from typing import Optional, Union
+
+# https://github.com/usnistgov/DataModelDict
 from DataModelDict import DataModelDict as DM
 
-from potentials.record import PotentialLAMMPS, PotentialLAMMPSKIM
+# https://github.com/usnistgov/potentials
+from potentials import load_record
+from potentials.record.BasePotentialLAMMPS import BasePotentialLAMMPS
 
-def Potential(model, name=None, pot_dir=None, kim_id=None, potkey=None,
-              potid=None, symbolset=None):
+def Potential(model: Union[str, io.IOBase],
+              name: Optional[str] = None,
+              pot_dir: Optional[str] = None,
+              kim_id: Optional[str] = None,
+              potkey: Optional[str] = None,
+              potid: Optional[str] = None,
+              symbolset: Union[str, list, None] = None
+              ) -> BasePotentialLAMMPS:
     """
     Class initializer switch for PotentialLAMMPS or PotentialLAMMPSKIM objects.
 
@@ -40,10 +53,8 @@ def Potential(model, name=None, pot_dir=None, kim_id=None, potkey=None,
     
     Returns
     -------
-    potentials.record.PotentialLAMMPS
-        Returned if model contains potential-LAMMPS content.
-    potentials.record.PotentialLAMMPSKIM
-        Returned if model contains potential-LAMMPS-KIM content.
+    potentials.record.BasePotentialLAMMPS.BasePotentialLAMMPS
+        The matching LAMMPS Potential object
     """
     model = DM(model)
     try:
@@ -53,10 +64,10 @@ def Potential(model, name=None, pot_dir=None, kim_id=None, potkey=None,
         try:
             # Search for potential-LAMMPS-KIM branch
             model.find('potential-LAMMPS-KIM')
-        except ValueError:
-            raise ValueError('Failed to find either potential-LAMMPS or potential-LAMMPS-KIM content')
+        except ValueError as err:
+            raise ValueError('Failed to find either potential-LAMMPS or potential-LAMMPS-KIM content') from err
         else:
-            return PotentialLAMMPSKIM(model=model, name=name, id=kim_id,
-                                      potkey=potkey, potid=potid, symbolset=symbolset)
+            return load_record('potential_LAMMPS_KIM', model=model, name=name, id=kim_id,
+                               potkey=potkey, potid=potid, symbolset=symbolset)
     else:
-        return PotentialLAMMPS(model=model, name=name, pot_dir=pot_dir)
\ No newline at end of file
+        return load_record('potential_LAMMPS', model=model, name=name, pot_dir=pot_dir)
\ No newline at end of file
