@@ -10,11 +10,7 @@ import numpy as np
 from ... import Atoms, Box, System
 
 # https://wiki.fysik.dtu.dk/ase/
-try:
-    import ase
-    has_ase = True
-except:
-    has_ase = False
+import ase
 
 def load(aseatoms: ase.Atoms,
          symbols: Optional[tuple] = None,
@@ -39,8 +35,6 @@ def load(aseatoms: ase.Atoms,
         A atomman representation of a system.
     """
     
-    assert has_ase, 'ase not imported'
-    
     if prop is None:
         prop = {}
 
