@@ -2,7 +2,9 @@
 
 from .Shape import Shape
 from .Plane import Plane
+from .PlaneSet import PlaneSet
 from .Sphere import Sphere
 from .Cylinder import Cylinder
 
-__all__ = ['Plane', 'Sphere', 'Cylinder', 'Shape']
\ No newline at end of file
+
+__all__ = ['Plane', 'PlaneSet', 'Sphere', 'Cylinder', 'Shape']
\ No newline at end of file
