@@ -2,16 +2,19 @@
 
 # http://www.numpy.org/
 import numpy as np
+import numpy.typing as npt
 
-def vect_angle(vect1, vect2, unit='degree'):
+def vect_angle(vect1: npt.ArrayLike,
+               vect2: npt.ArrayLike,
+               unit: str = 'degree') -> float:
     """
     Returns the angle between two vectors.
     
     Parameters
     ----------
-    vect1 : list or numpy.ndarray
+    vect1 : array-like object
         First vector.
-    vect2 : list or numpy.ndarray
+    vect2 : array-like object
         Second vector.
     unit : str
         Specifies unit of returned angle: 'degree' or 'radian'. Default value
